import { Except } from 'type-fest';
interface Options {
    from: string;
    to: string;
    base: string;
    rates: object;
}
declare class Cashify {
    /**
    * @param {string} base Base currency
    * @param {object} rates Object containing currency rates (for example from an API, such as Open Exchange Rates)
    */
    readonly options: Except<Options, 'from' | 'to'>;
    constructor({ base, rates }: Except<Options, 'from' | 'to'>);
    /**
    * @param {number} amount Amount of money you want to convert
    * @param {object} options Conversion options
    * @param {string} options.from Currency from which you want to convert
    * @param {string} options.to Currency to which you want to convert
    * @return {number} Conversion result
    */
    convert(amount: number, { from, to }: Except<Options, 'base' | 'rates'>): number;
}
/**
* @param {number} amount Amount of money you want to convert
* @param {object} options Conversion options
* @param {string} options.from Currency from which you want to convert
* @param {string} options.to Currency to which you want to convert
* @param {string} options.base Base currency
* @param {string} options.rates Object containing currency rates (for example from an API, such as Open Exchange Rates)
* @return {number} Conversion result
*/
declare const convert: (amount: number, { from, to, base, rates }: Options) => number;
export { Cashify, convert };
